@@ -1,6 +1,6 @@
 ;; examples/nyacc/lang/c99/tryit.scm
 
-;; Copyright (C) 2020 Matthew R. Wette
+;; Copyright (C) 2020-2021 Matthew R. Wette
 ;; 
 ;; Copying and distribution of this file, with or without modification,
 ;; are permitted in any medium without royalty provided the copyright
@@ -16,11 +16,14 @@
 (use-modules (nyacc lang c99 munge-base))
 (use-modules (nyacc lang c99 cpp))
 (use-modules (nyacc lang c99 util))
+(use-modules (nyacc lang c99 ffi-help))
 (use-modules (nyacc lang sx-util))
 (use-modules (nyacc lang util))
 (use-modules (nyacc lex))
 (use-modules (nyacc util))
 (use-modules (sxml fold))
+(use-modules (sxml xpath))
+(use-modules ((srfi srfi-1) #:select (fold-right)))
 (use-modules (ice-9 pretty-print))
 
 (define (sf fmt . args) (apply simple-format #t fmt args))
@@ -91,20 +94,6 @@
   (define (fH seed node) (cons node seed))
   (foldts fD fU fH '() tree))
 
-(define (fix-tree tree)
-  (define (fD seed tree) '())
-  (define (fU seed kseed tree)
-    (case (car tree)
-      ((include)
-       (let ((t (reverse (cdr kseed))))
-	 (if (pair? seed) (cons t seed) t)))
-      ((comment) seed)
-      (else
-       (let ((t (reverse kseed)))
-	 (if (pair? seed) (cons t seed) t)))))
-  (define (fH seed node) (cons node seed))
-  (foldts fD fU fH '() tree))
-
 (when #f
   (let* ((code "int foo = sizeof(int(*)());")
 	 (tree (or (parse-string code) (error "parse failed")))
@@ -118,7 +107,6 @@
     (pp expr)
     (sf "evaluate:\n")
     (sf "x = ~S\n" (eval-c99-cx expr))))
-
 (when #f
   (let* ((code "int intx;\n")
 	 (tree (or (parse-string code) (error "parse failed")))
@@ -127,65 +115,206 @@
     (ppin tree)
     (pp99 tree)
     ))
+(when #f
+  (let* ((code "int foo(int x) asm(\"foo\");")
+	 ;;(code "int foo(int x);")
+	 (tree (parse-string code)))
+    (pp code) (pp tree) (pp99 tree) (newline)
+    ))
+(when #f
+  (let* ((code "*(x->y->z)")
+	 (tree (parse-c99x code)))
+    (pp code) (pp tree) (pp99 tree) (newline)
+    ))
+(when #f
+  (let* ((code
+	  (string-append
+	   "void foo() { __asm__ goto (\"mov r0,r1\" : "
+	   ": [mcu] \"I\" (123), [ssr] \"X\" (456) "
+	   " : \"foo\", \"bar\" : error ); }"))
+	 (tree (parse-string code #:mode 'decl))
+ 	 )
+    (pp tree)
+    #t))
 
-(when #t
-  (let* ((code 
-	  "if (((Rd & 0x08) && (Rr & 0x08)) ||
-              ((Rr & 0x08) && (~Ru & 0x08)) ||
-              ((~Ru & 0x08) && (Rd & 0x08))) {
-            sreg = SREG_SET_H(sreg);
-          } else {
-            sreg = SREG_CLR_H(sreg);
-          }
-        
-          if (((Rd & 0x80) && (Rr & 0x80) && (~Ru & 0x80)) ||
-              ((~Rd & 0x80) && (~Rr & 0x80) && (Ru & 0x80))) {
-            sreg = SREG_SET_V(sreg);
-          } else {
-            sreg = SREG_CLR_V(sreg);
-          }
-        
-          sreg = set_N(sreg, Ru);
-          sreg = set_S(sreg);
-          sreg = set_Z(sreg, Ru);
-        
-          if (((Rd & 0x80) && (Rr & 0x80)) ||
-              ((Rr & 0x80) && (~Ru & 0x80)) ||
-              ((~Ru & 0x80) && (Rd & 0x80))) {
-            sreg = SREG_SET_C(sreg);
-          } else {
-            sreg = SREG_CLR_C(sreg);
-          }")
-	 (code (string-append "void foo() {\n" code "}\n"))
-	 (tree (or (parse-string code) (error "parse failed")))
-	 (tree (sx-ref* tree 1 3 1))
-	 )
-    (sf "~A\n" code)
-    (ppin tree)
-    ;;(pp99 tree)
+(when #f
+  (let* ((code
+	  (string-append
+	   "#define sei() __asm__ __volatile__ (\"sei\" ::: \"memory\")\n"
+	   "int foo() { sei(); }\n"
+	   ))
+	 (tree (parse-string code #:mode 'code))
+ 	 )
+    #t))
+(when #f
+  (let* ((code "int foo() { spice->meas[1].pin = &mega->portD.pin[0]; }\n")
+	 (tree (parse-string code #:mode 'code)))
+    (pp tree)
+    #t))
+
+(when #f
+  (let* ((code
+	  (string-append
+	   "#define ISR(vector, ...) void vector (__VA_ARGS__) \n"
+	   "ISR(__vector__12__) { int x; }\n"))
+	 (tree (parse-string code #:mode 'code)))
+    (pp tree)
+    (pp99 tree)
     ))
 
+(when #f
+  (let* ((code "typedef enum { A, B=3, C } foo;")
+	 (tree (or (parse-string code) (error "parse failed")))
+	 (udict (c99-trans-unit->udict tree))
+	 (udecl (assoc-ref udict "foo"))
+	 (edl (sx-ref* udecl 1 2 1 1))
+	 (xxx (canize-enum-def-list edl))
+	 )
+    (pp udecl)
+    (pp edl)
+    (pp xxx)
+    ))
 
-;; ffi-help patterns:
-;; Figure out how to have ffi-help print message when new pattern shows up.
-;;
-;; typedef struct foo *bar_t;
-;; struct foo; typedef struct foo *bar_t; stuct foo { int a; };
-;; typedef struct foo bar_t; struct foo { int a; }; typedef bar_t *baz_t;
-;; struct foo { int a; }; typedef struct foo bar_t;
-;; struct foo { int a; }; typedef struct foo *bar_t;
+(when #f
+  (let* ((code
+	  (string-append
+	   #|
+	   "int foo() {\n"
+	   "  typedef int foo_t;\n"
+	   "  {\n"
+	   "    typedef int foo_t[3];\n"
+	   "    1;\n"
+	   "  }\n"
+	   "}\n"
+	   |#
+	   "typedef int foo_t;\n"
+	   "int foo() {\n"
+	   "  typedef int foo_t[3];\n"
+	   "  1;\n"
+	   "}\n"
+	   ))
+	 (tree (parse-string code #:mode 'code)))
+    (pp tree)))
 
-;; struct foo; int baz(struct foo*); 
+(when #f                               ; bug #60474
+  (let* ((code
+	  (string-append
+	   "const int x = 1;\n"
+	   ))
+	 (tree (parse-string code #:mode 'code))
+	 (udict (c99-trans-unit->udict tree))
+	 (udecl (assoc-ref udict "x"))
+	 (specl (sx-ref udecl 1))
+	 (declr (sx-ref udecl 2))
+	 )
+    (pp udecl)
+    (call-with-values (lambda () (cleanup-udecl specl declr))
+      (lambda (specl declr)
+	(pp `(udecl ,specl ,declr))))
+    ))
 
-;; case 1
-;; typedef struct foo *bar_t; struct foo { int a; }; =>
-;; (define struct-foo-desc 'void)
-;; (define bar_t (fh:pointer (delay struct-foo-desc)))
-;; (define-ffi-pointer-type bar_t struct-foo-desc bar_t? make-bar_t)
-;;
-;; (set! struct-foo-desc (bs:struct (list `(a ,int))))
-;; (define-fh-compound-type struct-foo struct-foo-desc
-;;                          struct-foo? make-struct-foo)
-;; (fh-ref-deref! bar_t* make-bar_t* struct-foo make-struct-foo)
+(when #f
+  (let* ((code
+	  (string-append
+	   "#define bar(X) #X\n"
+	   "#define foo(X) bar(X)\n"
+	   "char *s = foo('abc');\n"))
+	 (tree (parse-string code #:mode 'decl)))
+    (pp tree)))
+
+(when #f
+  (let* ((code
+	  (string-append
+           "#if 1\n"
+           "#define g_abort() abort ()\n"
+           "#else\n"
+           "void g_abort (void);\n"
+           "#endif\n"
+           "int x;\n"))
+	   (tree (parse-string code #:mode 'decl)))
+	  (pp tree)
+	  ))
+
+(when #f
+  (let* ((code
+	  (string-append
+	   "typedef struct { int x; double y; } foo_t;\n"
+	   ;;"void bar(foo_t);\n"
+	   "int x = sizeof(foo_t);\n"
+	   ))
+	 (tree (parse-string code #:mode 'code))
+	 )
+    (pp tree)
+    ))
+
+(when #f
+  (let* ((code
+	  (string-append
+	   "const int x = 1;\n"
+	   ))
+	 (tree (parse-string code #:mode 'code))
+	 (udict (c99-trans-unit->udict tree))
+	 (udecl (assoc-ref udict "x"))
+	 (specl (sx-ref udecl 1))
+	 (declr (sx-ref udecl 2))
+	 )
+    (pp udecl)
+    (pp (cleanup-udecl specl declr))
+    ))
+
+(when #f
+  (let* ((code
+	  (string-append
+	   "typedef struct {\n"
+	   " int x;\n"
+	   " union { int a; int b; };\n"
+	   " int y;\n"
+	   " union { int c[3]; double d; };\n"
+	   ;;" int z;\n"
+	   "} foo_t;\n"
+	   "foo_t s1;\n"
+	   ))
+	 (tree (parse-string code #:mode 'code))
+	 (udict (c99-trans-unit->udict tree))
+	 (udecl (assoc-ref udict "s1"))
+	 (udecl (expand-typerefs udecl udict))
+	 (mdecl (udecl->mdecl udecl))
+	 (mtail (cdr mdecl))
+	 )
+    ;;(pp tree)
+    ;;(pp udecl)
+    ;;(pp mdecl)
+    ;;(pp (mtail->bs-desc mtail))
+    (pp (mtail->ffi-desc mtail))
+    ))
+
+(when #f				; bug #60474
+  (let* ((code
+	  (string-append
+	   "const int x = 1;\n"
+	   ))
+	 (tree (parse-string code #:mode 'code))
+	 (udict (c99-trans-unit->udict tree))
+	 (udecl (assoc-ref udict "x"))
+	 (specl (sx-ref udecl 1))
+	 (declr (sx-ref udecl 2))
+	 )
+    (pp udecl)
+    (call-with-values (lambda () (cleanup-udecl specl declr))
+      (lambda (specl declr)
+	(pp `(udecl ,specl ,declr))))
+    ))
+
+(when #f
+  (let* ((code "typedef int foo_t; foo_t foo[] = { 1, 2, 3, 4 };" )
+	 (tree (parse-string code #:mode 'decl))
+	 (udict (c99-trans-unit->udict tree))
+	 ;;(udecl (assoc-ref udict "x"))
+	 ;;(specl (sx-ref udecl 1))
+	 ;;(declr (sx-ref udecl 2))
+	 )
+    (pp tree)
+    (pp udict)
+    ))
 
 ;; --- last line ---
