@@ -22,7 +22,7 @@
    (lambda ($3 $2 $1 . $rest) $2)
    ;; primary-expression => "(" "{" $P1 block-item-list $P2 "}" ")"
    (lambda ($7 $6 $5 $4 $3 $2 $1 . $rest)
-     `(stmt-expr (@ (extension "GNUC")) ,$4))
+     `(stmt-expr (@ (extension "GNUC")) ,(tl->list $4)))
    ;; $P1 => 
    (lambda ($2 $1 . $rest) (cpi-push))
    ;; $P2 => 
@@ -257,6 +257,18 @@
    (lambda ($1 . $rest) `(type-spec ,$1))
    ;; type-specifier => typedef-name
    (lambda ($1 . $rest) `(type-spec ,$1))
+   ;; type-specifier => "typeof" "(" unary-expression ")"
+   (lambda ($4 $3 $2 $1 . $rest) `(typeof-expr ,$3))
+   ;; type-specifier => "typeof" "(" type-name ")"
+   (lambda ($4 $3 $2 $1 . $rest) `(typeof-type ,$3))
+   ;; type-specifier => "__typeof" "(" unary-expression ")"
+   (lambda ($4 $3 $2 $1 . $rest) `(typeof-expr ,$3))
+   ;; type-specifier => "__typeof" "(" type-name ")"
+   (lambda ($4 $3 $2 $1 . $rest) `(typeof-type ,$3))
+   ;; type-specifier => "__typeof__" "(" unary-expression ")"
+   (lambda ($4 $3 $2 $1 . $rest) `(typeof-expr ,$3))
+   ;; type-specifier => "__typeof__" "(" type-name ")"
+   (lambda ($4 $3 $2 $1 . $rest) `(typeof-type ,$3))
    ;; fixed-type-specifier => "short"
    (lambda ($1 . $rest) '(fixed-type "short"))
    ;; fixed-type-specifier => "short" "int"
@@ -335,6 +347,8 @@
    ;; float-type-specifier => "long" "double"
    (lambda ($2 $1 . $rest)
      '(float-type "long double"))
+   ;; float-type-specifier => "_Float128"
+   (lambda ($1 . $rest) '(float-type "_Float128"))
    ;; complex-type-specifier => "_Complex"
    (lambda ($1 . $rest) '(complex-type "_Complex"))
    ;; complex-type-specifier => "float" "_Complex"
@@ -573,12 +587,15 @@
    (lambda ($2 $1 . $rest) `(enum-defn ,$1 ,$2))
    ;; enumerator => identifier "=" constant-expression
    (lambda ($3 $2 $1 . $rest) `(enum-defn ,$1 ,$3))
+   ;; enumerator => identifier attribute-specifiers "=" constant-expression
+   (lambda ($4 $3 $2 $1 . $rest)
+     `(enum-defn ,$1 ,$2 ,$4))
    ;; type-qualifier => "const"
-   (lambda ($1 . $rest) `(type-qual ,$1))
+   (lambda ($1 . $rest) `(type-qual (const)))
    ;; type-qualifier => "volatile"
-   (lambda ($1 . $rest) `(type-qual ,$1))
+   (lambda ($1 . $rest) `(type-qual (volatile)))
    ;; type-qualifier => "restrict"
-   (lambda ($1 . $rest) `(type-qual ,$1))
+   (lambda ($1 . $rest) `(type-qual (restrict)))
    ;; function-specifier => "inline"
    (lambda ($1 . $rest) `(fctn-spec ,$1))
    ;; function-specifier => "_Noreturn"
@@ -704,7 +721,7 @@
      `(ary-declr ,$1 ,$4 ,$5))
    ;; direct-declarator => direct-declarator "[" type-qualifier-list "stati...
    (lambda ($6 $5 $4 $3 $2 $1 . $rest)
-     `(ary-declr ,$1 ,4 ,$5))
+     `(ary-declr ,$1 (static) ,$5))
    ;; direct-declarator => direct-declarator "[" type-qualifier-list "*" "]"
    (lambda ($5 $4 $3 $2 $1 . $rest)
      `(ary-declr ,$1 ,$3 (var-len)))
@@ -756,7 +773,7 @@
    (lambda ($3 $2 $1 . $rest) (tl-append $1 $3))
    ;; type-name => specifier-qualifier-list/no-attr abstract-declarator
    (lambda ($2 $1 . $rest) `(type-name ,$1 ,$2))
-   ;; type-name => declaration-specifiers
+   ;; type-name => specifier-qualifier-list/no-attr
    (lambda ($1 . $rest) `(type-name ,$1))
    ;; abstract-declarator => pointer direct-abstract-declarator
    (lambda ($2 $1 . $rest) `(ptr-declr ,$1 ,$2))
@@ -787,18 +804,18 @@
    (lambda ($6 $5 $4 $3 $2 $1 . $rest)
      `(ary-declr
         ,$1
-        ,(tl->list (tl-insert $4 '(stor-spec "static")))
+        ,(tl->list (tl-insert $4 '(stor-spec (static))))
         ,$5))
    ;; direct-abstract-declarator => direct-abstract-declarator "[" "static"...
    (lambda ($5 $4 $3 $2 $1 . $rest)
      `(ary-declr
         ,$1
-        ,(tl->list (tl-insert $4 '(stor-spec "static")))))
+        ,(tl->list (tl-insert $4 '(stor-spec (static))))))
    ;; direct-abstract-declarator => direct-abstract-declarator "[" type-qua...
    (lambda ($6 $5 $4 $3 $2 $1 . $rest)
      `(ary-declr
         ,$1
-        ,(tl->list (tl-insert $3 '(stor-spec "static")))
+        ,(tl->list (tl-insert $3 '(stor-spec (static))))
         ,$5))
    ;; direct-abstract-declarator => direct-abstract-declarator "[" "*" "]"
    (lambda ($4 $3 $2 $1 . $rest)
@@ -820,16 +837,16 @@
    ;; direct-abstract-declarator => "[" "static" type-qualifier-list assign...
    (lambda ($5 $4 $3 $2 $1 . $rest)
      `(abs-ary-declr
-        ,(tl->list (tl-insert $3 '(stor-spec "static")))
+        ,(tl->list (tl-insert $3 '(stor-spec (static))))
         ,$4))
    ;; direct-abstract-declarator => "[" "static" type-qualifier-list "]"
    (lambda ($4 $3 $2 $1 . $rest)
      `(abs-ary-declr
-        ,(tl->list (tl-insert $3 '(stor-spec "static")))))
+        ,(tl->list (tl-insert $3 '(stor-spec (static))))))
    ;; direct-abstract-declarator => "[" type-qualifier-list "static" assign...
    (lambda ($5 $4 $3 $2 $1 . $rest)
      `(abs-ary-declr
-        ,(tl->list (tl-insert $2 '(stor-spec "static")))
+        ,(tl->list (tl-insert $2 '(stor-spec (static))))
         ,$4))
    ;; direct-abstract-declarator => "[" "*" "]"
    (lambda ($3 $2 $1 . $rest) '(abs-star-ary-declr))
@@ -985,6 +1002,10 @@
         ,$8))
    ;; opt-asm-qualifiers => 
    (lambda $rest (list))
+   ;; opt-asm-qualifiers => "__volatile__"
+   (lambda ($1 . $rest) (list '(volatile "true")))
+   ;; opt-asm-qualifiers => "__goto__"
+   (lambda ($1 . $rest) (list '(goto "true")))
    ;; opt-asm-qualifiers => "volatile"
    (lambda ($1 . $rest) (list '(volatile "true")))
    ;; opt-asm-qualifiers => "goto"
@@ -1101,8 +1122,6 @@
    (lambda ($1 . $rest) `(cpp-stmt ,$1))
    ;; pragma => '$pragma
    (lambda ($1 . $rest) `(pragma ,$1))
-   ;; pragma => "_Pragma" "(" string-literal ")"
-   (lambda ($4 $3 $2 $1 . $rest) `(pragma ,$3))
    ))
 
 ;;; end tables
