@@ -1,6 +1,6 @@
 ;;; nyacc/parse.scm
 
-;; Copyright (C) 2014-2018 Matthew R. Wette
+;; Copyright (C) 2014-2020 Matthew R. Wette
 ;;
 ;; This library is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public
@@ -30,6 +30,12 @@
 (define $default 1)			; sync w/ lalr.scm
 (define $error 2)			; sync w/ lalr.scm
 
+(use-modules (ice-9 pretty-print))
+(define (pperr exp)
+  (pretty-print exp (current-error-port) #:per-line-prefix "  "))
+(define (sferr fmt . args)
+  (apply simple-format (current-error-port) fmt args))
+
 (define (vector-map proc vec)		; see (srfi srfi-43)
   (let* ((ln (vector-length vec)) (res (make-vector ln)))
     (let loop ((ix 0))
@@ -51,9 +57,6 @@
 		    (eval f (or env (current-module))))
 		  (vector-map (lambda (ix actn) (wrap-action actn)) av))))
 
-(define (sferr fmt . args)
-  (apply simple-format (current-error-port) fmt args))
-
 (define (dmsg/n s t a ntab)
   (let ((t (or (assq-ref ntab t) t)))
     (cond
@@ -78,7 +81,9 @@
 	   "~A:~A: parse failed at state ~A, on input ~S"
 	   fn ln (car state) (cdr laval))))
 
-(define* (make-lalr-parser/sym mach #:key (skip-if-unexp '()) interactive env)
+(define* (make-lalr-parser/sym mach
+			       #:key (skip-if-unexp '()) interactive
+			       track-src-loc env)
   (let* ((len-v (assq-ref mach 'len-v))
 	 (rto-v (assq-ref mach 'rto-v))
 	 (pat-v (assq-ref mach 'pat-v))
@@ -127,7 +132,9 @@
 	     (else			; accept
 	      (car stack))))))))))
 
-(define* (make-lalr-parser/num mach #:key (skip-if-unexp '()) interactive env)
+(define* (make-lalr-parser/num mach
+			       #:key (skip-if-unexp '())
+			       interactive track-src-loc env)
   (let* ((len-v (assq-ref mach 'len-v))
 	 (rto-v (assq-ref mach 'rto-v))
 	 (pat-v (assq-ref mach 'pat-v))
@@ -200,6 +207,9 @@
 ;; If @code{#t}, this tells the parser that this is being called
 ;; interactively, so that the token @code{$end} is not expected.
 ;; The default value is @code{#f}.
+;; @item #:track-src-loc 
+;; If @code{#t}, propagate source location information.  This requires
+;; that the lexer execute [to be documented].
 ;; @item #:env
 ;; Use the passed environment to the parser actions provided in the
 ;; specification.  This can be a module (e.g., @code{(current-module)}
@@ -209,7 +219,12 @@
 ;; @end table
 ;; @noindent
 ;; @end deffn
-(define* (make-lalr-parser mach #:key (skip-if-unexp '()) interactive env)
+(define* (make-lalr-parser mach
+			   #:key
+			   (skip-if-unexp '())
+			   interactive
+			   track-src-loc
+			   env)
   "- Procedure: make-lalr-parser mach [options] => parser
      Generate a procedure for parsing a language, where MACH is a
      machine generated by 'make-lalr-machine'.  This generates a
@@ -227,6 +242,9 @@
           If '#t', this tells the parser that this is being called
           interactively, so that the token '$end' is not expected.  The
           default value is '#f'.
+     '#:track-src-loc'
+          If '#t', propagate source location information.  This requires
+          that the lexer execute [to be documented].
      '#:env'
           Use the passed environment to the parser actions provided in
           the specification.  This can be a module (e.g.,
@@ -238,18 +256,19 @@
   ;; BUG: this should fail if rrconf exists.
 
   (let* ((mtab (assq-ref mach 'mtab))
-	 (siu (map (lambda (n) (assoc-ref mtab n)) skip-if-unexp))
-	 (iact interactive))
+	 (siu (map (lambda (n) (assoc-ref mtab n)) skip-if-unexp)))
     (if (number? (caar (vector-ref (assq-ref mach 'pat-v) 0)))
 	;; hashed:
 	(make-lalr-parser/num mach
 			      #:skip-if-unexp siu
-			      #:interactive iact
+			      #:interactive interactive
+			      #:track-src-loc track-src-loc
 			      #:env env)
 	;; not hashed:
 	(make-lalr-parser/sym mach
 			      #:skip-if-unexp siu
-			      #:interactive iact
+			      #:interactive interactive
+			      #:track-src-loc track-src-loc
 			      #:env env))))
 
 ;;; --- last line ---
